@@ -20,6 +20,7 @@ import sys
 from os import path
 import os
 import time
+from typing_extensions import Required
 from calculate.core.server.gen_pid import search_worked_process
 from calculate.core.setup_cache import Cache as SetupCache
 from calculate.core.server.func import MethodsInterface
@@ -1691,7 +1692,8 @@ class Update(MethodsInterface):
         return True
 
     def get_migration_mirror_url(self, host, level):
-        return f"{host}level{level}"
+        level_required = int(level) + 1
+        return f"{host}level{level_required}"
 
     @variable_module("update")
     def detect_best_binhost(self):
@@ -1823,5 +1825,8 @@ class Update(MethodsInterface):
         return True
 
     def update_set_current_level(self):
-        self.clVars.Set('update.cl_update_level',
-                Variable.On, force=True)
\ No newline at end of file
+        current_level = int(self.clVars.Get('cl_update_level'))
+        self.clVars.Write('cl_update_level', 
+                str(current_level + 1), location="system")
+        self.clVars.Set("update.cl_update_use_migration_host",
+                Variable.Off)
\ No newline at end of file
