@@ -1857,11 +1857,11 @@ class VariableClUpdateLevel(Variable):
     Текущий уровень обновления
     Используется для выбора зеркала
     """
-    value = "0"
+    type = "int"
 
 class VariableClUpdateUseMigrationHost(Variable):
     """
-    Уровень обновления на бинхосте
+    Использовать хост миграции
     """
     type = "bool"
     value = "off"
